@@ -102,7 +102,7 @@ class Cloud9Client(BaseClient):
         imageId: str = ...,
         automaticStopTimeMinutes: int = ...,
         ownerArn: str = ...,
-        tags: Sequence["TagTypeDef"] = ...,
+        tags: Sequence[TagTypeDef] = ...,
         connectionType: ConnectionTypeType = ...,
         dryRun: bool = ...
     ) -> CreateEnvironmentEC2ResultTypeDef:
@@ -210,7 +210,7 @@ class Cloud9Client(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client/#list_tags_for_resource)
         """
 
-    def tag_resource(self, *, ResourceARN: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceARN: str, Tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Adds tags to an Cloud9 development environment.
 
