@@ -6,9 +6,9 @@ Type annotations for cloud9 service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_cloud9.type_defs import CreateEnvironmentEC2RequestRequestTypeDef
+    from mypy_boto3_cloud9.type_defs import TagTypeDef
 
-    data: CreateEnvironmentEC2RequestRequestTypeDef = {...}
+    data: TagTypeDef = {...}
     ```
 """
 import sys
@@ -33,73 +33,53 @@ else:
 
 
 __all__ = (
-    "CreateEnvironmentEC2RequestRequestTypeDef",
-    "CreateEnvironmentEC2ResultTypeDef",
+    "TagTypeDef",
+    "ResponseMetadataTypeDef",
     "CreateEnvironmentMembershipRequestRequestTypeDef",
-    "CreateEnvironmentMembershipResultTypeDef",
+    "EnvironmentMemberTypeDef",
     "DeleteEnvironmentMembershipRequestRequestTypeDef",
     "DeleteEnvironmentRequestRequestTypeDef",
-    "DescribeEnvironmentMembershipsRequestDescribeEnvironmentMembershipsPaginateTypeDef",
-    "DescribeEnvironmentMembershipsRequestRequestTypeDef",
-    "DescribeEnvironmentMembershipsResultTypeDef",
-    "DescribeEnvironmentStatusRequestRequestTypeDef",
-    "DescribeEnvironmentStatusResultTypeDef",
-    "DescribeEnvironmentsRequestRequestTypeDef",
-    "DescribeEnvironmentsResultTypeDef",
-    "EnvironmentLifecycleTypeDef",
-    "EnvironmentMemberTypeDef",
-    "EnvironmentTypeDef",
-    "ListEnvironmentsRequestListEnvironmentsPaginateTypeDef",
-    "ListEnvironmentsRequestRequestTypeDef",
-    "ListEnvironmentsResultTypeDef",
-    "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResponseTypeDef",
     "PaginatorConfigTypeDef",
-    "ResponseMetadataTypeDef",
-    "TagResourceRequestRequestTypeDef",
-    "TagTypeDef",
+    "DescribeEnvironmentMembershipsRequestRequestTypeDef",
+    "DescribeEnvironmentStatusRequestRequestTypeDef",
+    "DescribeEnvironmentsRequestRequestTypeDef",
+    "EnvironmentLifecycleTypeDef",
+    "ListEnvironmentsRequestRequestTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "UpdateEnvironmentMembershipRequestRequestTypeDef",
-    "UpdateEnvironmentMembershipResultTypeDef",
     "UpdateEnvironmentRequestRequestTypeDef",
-)
-
-_RequiredCreateEnvironmentEC2RequestRequestTypeDef = TypedDict(
-    "_RequiredCreateEnvironmentEC2RequestRequestTypeDef",
-    {
-        "name": str,
-        "instanceType": str,
-    },
-)
-_OptionalCreateEnvironmentEC2RequestRequestTypeDef = TypedDict(
-    "_OptionalCreateEnvironmentEC2RequestRequestTypeDef",
-    {
-        "description": str,
-        "clientRequestToken": str,
-        "subnetId": str,
-        "imageId": str,
-        "automaticStopTimeMinutes": int,
-        "ownerArn": str,
-        "tags": Sequence["TagTypeDef"],
-        "connectionType": ConnectionTypeType,
-        "dryRun": bool,
-    },
-    total=False,
-)
-
-
-class CreateEnvironmentEC2RequestRequestTypeDef(
-    _RequiredCreateEnvironmentEC2RequestRequestTypeDef,
-    _OptionalCreateEnvironmentEC2RequestRequestTypeDef,
-):
-    pass
-
-
-CreateEnvironmentEC2ResultTypeDef = TypedDict(
+    "CreateEnvironmentEC2RequestRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "CreateEnvironmentEC2ResultTypeDef",
+    "DescribeEnvironmentStatusResultTypeDef",
+    "ListEnvironmentsResultTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "CreateEnvironmentMembershipResultTypeDef",
+    "DescribeEnvironmentMembershipsResultTypeDef",
+    "UpdateEnvironmentMembershipResultTypeDef",
+    "DescribeEnvironmentMembershipsRequestDescribeEnvironmentMembershipsPaginateTypeDef",
+    "ListEnvironmentsRequestListEnvironmentsPaginateTypeDef",
+    "EnvironmentTypeDef",
+    "DescribeEnvironmentsResultTypeDef",
+)
+
+TagTypeDef = TypedDict(
+    "TagTypeDef",
     {
-        "environmentId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "Key": str,
+        "Value": str,
+    },
+)
+
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -112,102 +92,6 @@ CreateEnvironmentMembershipRequestRequestTypeDef = TypedDict(
     },
 )
 
-CreateEnvironmentMembershipResultTypeDef = TypedDict(
-    "CreateEnvironmentMembershipResultTypeDef",
-    {
-        "membership": "EnvironmentMemberTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DeleteEnvironmentMembershipRequestRequestTypeDef = TypedDict(
-    "DeleteEnvironmentMembershipRequestRequestTypeDef",
-    {
-        "environmentId": str,
-        "userArn": str,
-    },
-)
-
-DeleteEnvironmentRequestRequestTypeDef = TypedDict(
-    "DeleteEnvironmentRequestRequestTypeDef",
-    {
-        "environmentId": str,
-    },
-)
-
-DescribeEnvironmentMembershipsRequestDescribeEnvironmentMembershipsPaginateTypeDef = TypedDict(
-    "DescribeEnvironmentMembershipsRequestDescribeEnvironmentMembershipsPaginateTypeDef",
-    {
-        "userArn": str,
-        "environmentId": str,
-        "permissions": Sequence[PermissionsType],
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-DescribeEnvironmentMembershipsRequestRequestTypeDef = TypedDict(
-    "DescribeEnvironmentMembershipsRequestRequestTypeDef",
-    {
-        "userArn": str,
-        "environmentId": str,
-        "permissions": Sequence[PermissionsType],
-        "nextToken": str,
-        "maxResults": int,
-    },
-    total=False,
-)
-
-DescribeEnvironmentMembershipsResultTypeDef = TypedDict(
-    "DescribeEnvironmentMembershipsResultTypeDef",
-    {
-        "memberships": List["EnvironmentMemberTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeEnvironmentStatusRequestRequestTypeDef = TypedDict(
-    "DescribeEnvironmentStatusRequestRequestTypeDef",
-    {
-        "environmentId": str,
-    },
-)
-
-DescribeEnvironmentStatusResultTypeDef = TypedDict(
-    "DescribeEnvironmentStatusResultTypeDef",
-    {
-        "status": EnvironmentStatusType,
-        "message": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeEnvironmentsRequestRequestTypeDef = TypedDict(
-    "DescribeEnvironmentsRequestRequestTypeDef",
-    {
-        "environmentIds": Sequence[str],
-    },
-)
-
-DescribeEnvironmentsResultTypeDef = TypedDict(
-    "DescribeEnvironmentsResultTypeDef",
-    {
-        "environments": List["EnvironmentTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-EnvironmentLifecycleTypeDef = TypedDict(
-    "EnvironmentLifecycleTypeDef",
-    {
-        "status": EnvironmentLifecycleStatusType,
-        "reason": str,
-        "failureResource": str,
-    },
-    total=False,
-)
-
 _RequiredEnvironmentMemberTypeDef = TypedDict(
     "_RequiredEnvironmentMemberTypeDef",
     {
@@ -232,70 +116,18 @@ class EnvironmentMemberTypeDef(
     pass
 
 
-_RequiredEnvironmentTypeDef = TypedDict(
-    "_RequiredEnvironmentTypeDef",
+DeleteEnvironmentMembershipRequestRequestTypeDef = TypedDict(
+    "DeleteEnvironmentMembershipRequestRequestTypeDef",
     {
-        "type": EnvironmentTypeType,
-        "arn": str,
-        "ownerArn": str,
-    },
-)
-_OptionalEnvironmentTypeDef = TypedDict(
-    "_OptionalEnvironmentTypeDef",
-    {
-        "id": str,
-        "name": str,
-        "description": str,
-        "connectionType": ConnectionTypeType,
-        "lifecycle": "EnvironmentLifecycleTypeDef",
-        "managedCredentialsStatus": ManagedCredentialsStatusType,
-    },
-    total=False,
-)
-
-
-class EnvironmentTypeDef(_RequiredEnvironmentTypeDef, _OptionalEnvironmentTypeDef):
-    pass
-
-
-ListEnvironmentsRequestListEnvironmentsPaginateTypeDef = TypedDict(
-    "ListEnvironmentsRequestListEnvironmentsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-ListEnvironmentsRequestRequestTypeDef = TypedDict(
-    "ListEnvironmentsRequestRequestTypeDef",
-    {
-        "nextToken": str,
-        "maxResults": int,
-    },
-    total=False,
-)
-
-ListEnvironmentsResultTypeDef = TypedDict(
-    "ListEnvironmentsResultTypeDef",
-    {
-        "nextToken": str,
-        "environmentIds": List[str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "environmentId": str,
+        "userArn": str,
     },
 )
 
-ListTagsForResourceRequestRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestRequestTypeDef",
+DeleteEnvironmentRequestRequestTypeDef = TypedDict(
+    "DeleteEnvironmentRequestRequestTypeDef",
     {
-        "ResourceARN": str,
-    },
-)
-
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "Tags": List["TagTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "environmentId": str,
     },
 )
 
@@ -309,30 +141,55 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
+DescribeEnvironmentMembershipsRequestRequestTypeDef = TypedDict(
+    "DescribeEnvironmentMembershipsRequestRequestTypeDef",
     {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
+        "userArn": str,
+        "environmentId": str,
+        "permissions": Sequence[PermissionsType],
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+DescribeEnvironmentStatusRequestRequestTypeDef = TypedDict(
+    "DescribeEnvironmentStatusRequestRequestTypeDef",
+    {
+        "environmentId": str,
     },
 )
 
-TagResourceRequestRequestTypeDef = TypedDict(
-    "TagResourceRequestRequestTypeDef",
+DescribeEnvironmentsRequestRequestTypeDef = TypedDict(
+    "DescribeEnvironmentsRequestRequestTypeDef",
+    {
+        "environmentIds": Sequence[str],
+    },
+)
+
+EnvironmentLifecycleTypeDef = TypedDict(
+    "EnvironmentLifecycleTypeDef",
+    {
+        "status": EnvironmentLifecycleStatusType,
+        "reason": str,
+        "failureResource": str,
+    },
+    total=False,
+)
+
+ListEnvironmentsRequestRequestTypeDef = TypedDict(
+    "ListEnvironmentsRequestRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
-        "Tags": Sequence["TagTypeDef"],
-    },
-)
-
-TagTypeDef = TypedDict(
-    "TagTypeDef",
-    {
-        "Key": str,
-        "Value": str,
     },
 )
 
@@ -353,14 +210,6 @@ UpdateEnvironmentMembershipRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateEnvironmentMembershipResultTypeDef = TypedDict(
-    "UpdateEnvironmentMembershipResultTypeDef",
-    {
-        "membership": "EnvironmentMemberTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredUpdateEnvironmentRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateEnvironmentRequestRequestTypeDef",
     {
@@ -382,3 +231,155 @@ class UpdateEnvironmentRequestRequestTypeDef(
     _RequiredUpdateEnvironmentRequestRequestTypeDef, _OptionalUpdateEnvironmentRequestRequestTypeDef
 ):
     pass
+
+
+_RequiredCreateEnvironmentEC2RequestRequestTypeDef = TypedDict(
+    "_RequiredCreateEnvironmentEC2RequestRequestTypeDef",
+    {
+        "name": str,
+        "instanceType": str,
+    },
+)
+_OptionalCreateEnvironmentEC2RequestRequestTypeDef = TypedDict(
+    "_OptionalCreateEnvironmentEC2RequestRequestTypeDef",
+    {
+        "description": str,
+        "clientRequestToken": str,
+        "subnetId": str,
+        "imageId": str,
+        "automaticStopTimeMinutes": int,
+        "ownerArn": str,
+        "tags": Sequence[TagTypeDef],
+        "connectionType": ConnectionTypeType,
+        "dryRun": bool,
+    },
+    total=False,
+)
+
+
+class CreateEnvironmentEC2RequestRequestTypeDef(
+    _RequiredCreateEnvironmentEC2RequestRequestTypeDef,
+    _OptionalCreateEnvironmentEC2RequestRequestTypeDef,
+):
+    pass
+
+
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+)
+
+CreateEnvironmentEC2ResultTypeDef = TypedDict(
+    "CreateEnvironmentEC2ResultTypeDef",
+    {
+        "environmentId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeEnvironmentStatusResultTypeDef = TypedDict(
+    "DescribeEnvironmentStatusResultTypeDef",
+    {
+        "status": EnvironmentStatusType,
+        "message": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListEnvironmentsResultTypeDef = TypedDict(
+    "ListEnvironmentsResultTypeDef",
+    {
+        "nextToken": str,
+        "environmentIds": List[str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": List[TagTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateEnvironmentMembershipResultTypeDef = TypedDict(
+    "CreateEnvironmentMembershipResultTypeDef",
+    {
+        "membership": EnvironmentMemberTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeEnvironmentMembershipsResultTypeDef = TypedDict(
+    "DescribeEnvironmentMembershipsResultTypeDef",
+    {
+        "memberships": List[EnvironmentMemberTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateEnvironmentMembershipResultTypeDef = TypedDict(
+    "UpdateEnvironmentMembershipResultTypeDef",
+    {
+        "membership": EnvironmentMemberTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeEnvironmentMembershipsRequestDescribeEnvironmentMembershipsPaginateTypeDef = TypedDict(
+    "DescribeEnvironmentMembershipsRequestDescribeEnvironmentMembershipsPaginateTypeDef",
+    {
+        "userArn": str,
+        "environmentId": str,
+        "permissions": Sequence[PermissionsType],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ListEnvironmentsRequestListEnvironmentsPaginateTypeDef = TypedDict(
+    "ListEnvironmentsRequestListEnvironmentsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+_RequiredEnvironmentTypeDef = TypedDict(
+    "_RequiredEnvironmentTypeDef",
+    {
+        "type": EnvironmentTypeType,
+        "arn": str,
+        "ownerArn": str,
+    },
+)
+_OptionalEnvironmentTypeDef = TypedDict(
+    "_OptionalEnvironmentTypeDef",
+    {
+        "id": str,
+        "name": str,
+        "description": str,
+        "connectionType": ConnectionTypeType,
+        "lifecycle": EnvironmentLifecycleTypeDef,
+        "managedCredentialsStatus": ManagedCredentialsStatusType,
+    },
+    total=False,
+)
+
+
+class EnvironmentTypeDef(_RequiredEnvironmentTypeDef, _OptionalEnvironmentTypeDef):
+    pass
+
+
+DescribeEnvironmentsResultTypeDef = TypedDict(
+    "DescribeEnvironmentsResultTypeDef",
+    {
+        "environments": List[EnvironmentTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
